@@ -6,7 +6,6 @@
  * @package    Timezone
  * @subpackage UnitTests
  */
-
 class Horde_Timezone_IcalendarTest extends Horde_Test_Case
 {
     public function testEurope()
@@ -36,23 +35,3 @@ class Horde_Timezone_IcalendarTest extends Horde_Test_Case
         );
     }
 }
-
-class Horde_Timezone_Mock extends Horde_Timezone
-{
-    protected $_zone;
-
-    public function __construct($zone)
-    {
-        parent::__construct();
-        $this->_zone = $zone;
-    }
-
-    protected function _download()
-    {
-    }
-
-    protected function _extractAndParse()
-    {
-        $this->_parse(file_get_contents(__DIR__ . '/fixtures/' . $this->_zone));
-    }
-}
